@@ -20,10 +20,12 @@ from tarfile import ExtractError
 from fnmatch import fnmatch
 import logging
 
-import subprocess
 import os
 import sys
 
+from subprocess import PIPE, Popen
+from cStringIO import StringIO
+
 join = os.path.join
 
 # make zc.buildout quiet
@@ -68,20 +70,37 @@ def savewd(function):
 class ReleaseError(Exception):
     pass
 
-def system(command, input=''):
-    i, o, e = os.popen3(command)
+def runwait(command, env={}, debug=False, input=None):
+    if env:
+        p = Popen(command, env=env, shell=True, stdin=PIPE,
+                  stdout=PIPE, stderr=PIPE)
+    else:
+        p = Popen(command, shell=True, stdin=PIPE,
+                  stdout=PIPE, stderr=PIPE)
+
     if input:
-        i.write(input)
-    i.close()
-    result = o.read()+e.read()
-    o.close()
-    e.close()
-    return result
+        p.stdin.write(input)
+    p.stdin.close()
+
+    stdout = StringIO()
+    output = 'x'
+    while output:
+        output = p.stdout.readline()
+        if debug:
+            sys.stdout.write(output)
+            sys.stdout.flush()
+        else:
+            stdout.write(output)
+    stdout.seek(0)
+    return p.wait(), stdout.read(), p.stderr.read()
+
+def system(command, input=''):
+    code, o, e = runwait(command, input=input)
+    return o + e
 
 def command(cmd):
     """returns a command result"""
-    return subprocess.Popen(cmd, shell=True,
-                            stdout=subprocess.PIPE).stdout
+    return Popen(cmd, shell=True, stdout=PIPE).stdout
 
 def check_command(cmd):
     """sends a command and check the result"""
