@@ -1,19 +1,4 @@
 # -*- coding: utf-8 -*-
-# Copyright (C)2007 Ingeniweb
-
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-
-# You should have received a copy of the GNU General Public License
-# along with this program; see the file COPYING. If not, write to the
-# Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 from subprocess import Popen, PIPE
 import os
 import shutil
@@ -22,10 +7,9 @@ import pkg_resources
 import subprocess
 import tempfile
 import sys
+from cStringIO import StringIO
 from ConfigParser import ConfigParser
 import datetime
-import docutils.examples
-from docutils.utils import SystemMessage
 
 from collective.releaser import base
 from collective.releaser.base import savewd
@@ -58,10 +42,10 @@ def get_metadata(name, package_path=None):
         raise ValueError('No setup.py file found in %s' % os.getcwd())
     name = name.replace('_', '-')
     command = '%s setup.py --%s' % (sys.executable, name)
-    p = Popen(command, shell=True, stdout=PIPE, stderr=PIPE)
+    env = {'PYTHONPATH':os.pathsep.join(sys.path)}
+    p = Popen(command, env=env, shell=True, stdout=PIPE, stderr=PIPE)
     return p.stdout.read().strip()
 
-
     import setuptools
     attrs = {}
     old = setuptools.setup
@@ -175,51 +159,6 @@ def _get_svn_paths():
     paths['branch'] = '%sbranches/%s' % (paths['root'], version)
     return paths
 
-def create_tag():
-    """creates a tag for the current version"""
-    if not base.has_svn_support():
-        raise base.ReleaseError('You need Subversion client')
-
-    version = get_version()
-    paths = _get_svn_paths()
-    root = paths['root']
-    tag_root = paths['tag_root']
-    tag = paths['tag']
-    trunk = paths['trunk']
-
-    # commiting trunk
-    base.svn_commit('preparing release %s' % version)
-
-    # checking if tag_root exists
-    base.svn_mkdir(tag_root)
-
-    # checking if the tag exists, if so, override it
-    base.svn_remove(tag)
-    base.svn_copy(trunk, tag, 'tag for %s release' % version)
-
-    # now let's work on the tag: making a few changes in setup.cfg
-    rep = tempfile.mkdtemp()
-    old_rep = os.getcwd()
-    try:
-        os.chdir(rep)
-        base.svn_checkout(tag, rep)
-        setup_file = os.path.join(rep, 'setup.cfg')
-        if os.path.exists(setup_file):
-            setup_cfg = ConfigParser()
-            setup_cfg.read([setup_file])
-            changed = False
-            if 'egg_info' in setup_cfg.sections():
-                for option in ('tag_build', 'tag_svn_revision'):
-                    if option in setup_cfg.options('egg_info'):
-                        setup_cfg.remove_option('egg_info', option)
-                        changed = True
-            if changed:
-                setup_cfg.write(open(setup_file, 'w'))
-            base.svn_commit('fixed setup.cfg for %s' % version)
-    finally:
-        os.chdir(old_rep)
-        shutil.rmtree(rep, ignore_errors=True)
-
 def _checkout_tag():
     version = get_version()
     paths = _get_svn_paths()
@@ -230,9 +169,12 @@ def _checkout_tag():
 def _run_setup(*args):
     old_args = sys.argv
     sys.argv = [sys.argv[0]] + list(args)
+    old_path = sys.path[:]
+    sys.path.insert(0, os.getcwd())
     __import__('setup')
     del sys.modules['setup']
     sys.argv = old_args
+    sys.path[:] = old_path
 
 def pypi_upload(commands):
     """upload into pypi"""
@@ -247,23 +189,3 @@ def pypi_upload(commands):
         base.display('Running "%s"' % command)
         _run_setup(*command.split())
 
-def get_long_description(package_path):
-    return get_metadata('long_description', package_path)
-
-def check_long_description(desc):
-    if isinstance(desc, str):
-        desc = desc.decode('utf8')
-    try:
-        docutils.examples.internals(desc)
-    except SystemMessage:
-        return False
-    return True
-
-def check_package(package_path=None):
-    if package_path is None:
-        package_path = os.getcwd()
-    desc = get_long_description(package_path)
-    if desc is None:
-        return True
-    return check_long_description(desc)
-
