@@ -16,8 +16,6 @@
 # Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 from multiprocessing import Pool
 from optparse import OptionParser
-from subprocess import PIPE, Popen
-from cStringIO import StringIO
 import ConfigParser
 from itertools import chain
 import os
@@ -35,7 +33,7 @@ from distutils.errors import DistutilsError
 
 from collective.releaser import base
 from collective.releaser import packet
-from collective.releaser.base import savewd, display, display_step
+from collective.releaser.base import savewd, display, display_step, runwait
 
 join = os.path.join
 
@@ -133,7 +131,9 @@ def make_release(version=None, release=None,
         base.svn_checkout(release, rep)
         os.chdir(rep)
         version_file = join(rep, 'version.txt')
-        open(version_file, 'w').write(version)
+        fd = open(version_file, 'w')
+        fd.write(version)
+        fd.close()
         base.svn_add(version_file)
         msg = 'Added version file to buildout.'
         display_step(msg, verbose)
@@ -294,7 +294,7 @@ def set_option(filename, section, option, value):
     if section not in config.sections():
         config.add_section(section)
     config.set(section, option, value)
-    fd = open(filename, 'wb')
+    fd = open(filename, 'w')
     try:
         config.write(fd)
     finally:
@@ -393,29 +393,11 @@ def _make_python(location='.'):
     else:
         return join(location, 'bin', 'python')
 
-def runwait(command, env={}, debug=False):
-    if env:
-        p = Popen(command, env=env, shell=True,
-                  stdout=PIPE, stderr=PIPE)
-    else:
-        p = Popen(command, shell=True,
-                  stdout=PIPE, stderr=PIPE)
-    stdout = StringIO()
-    output = 'x'
-    while output:
-        output = p.stdout.readline()
-        if debug:
-            sys.stdout.write(output)
-            sys.stdout.flush()
-        else:
-            stdout.write(output)
-    stdout.seek(0)
-    return p.wait(), stdout.read(), p.stderr.read()
-
 @savewd
 def deploy_release(path=None, target=None, archiving='full'):
     """deploy a release in-place"""
     buildout_args = '-v'
+    force_upgrade = False
     if path is None:
         usage = '%prog [options] [http://to/your/buildout/]config.cfg]'
         parser = OptionParser(usage=usage)
@@ -425,6 +407,9 @@ def deploy_release(path=None, target=None, archiving='full'):
         parser.add_option("-D", "--debug", dest="debug",
                           help="enable debug mode",
                           default=False, action="store_true")
+        parser.add_option("-U", "--upgrade", dest="upgrade",
+                          help="Force the setuptools/zc.buildout upgrade",
+                          default=False, action="store_true")
         options, args = parser.parse_args()
         if len(args) != 1:
             parser.parse_args(['-h'])
@@ -433,28 +418,30 @@ def deploy_release(path=None, target=None, archiving='full'):
             buildout_args += 'vv'
         if options.debug:
             buildout_args += ' -D'
-
-    location, filename = parse_url(path)
-    folder = location.split('/')[-1]
+        if options.upgrade:
+            force_upgrade = True
 
     if os.path.isfile(path):
-        display("Using local configuration file %s" % filename)
+        path = os.path.abspath(path)
         target, filename = os.path.split(path)
+        display("Using local configuration file %s" % filename)
         release_name = filename.split('.')[0]
     else:
+        location, filename = parse_url(path)
+        folder = location.split('/')[-1]
         display("Using network file %s with url %s" % (filename, location))
         release_name = '%s-%s' % (folder, filename.split('.')[0])
 
     if not target:
         target = release_name
 
-    if os.path.isfile(path) or os.path.isdir(path):
-        target = location
+    if os.path.isdir(path):
+        root = path
+    else:
+        root = os.path.realpath(target)
 
-    if not os.path.isdir(target):
-        os.mkdir(target)
-
-    root = os.path.realpath(target)
+    if not os.path.isdir(root):
+        os.makedirs(root)
     os.chdir(root)
 
     # XXX at this time we are rebuilding everything
@@ -464,13 +451,18 @@ def deploy_release(path=None, target=None, archiving='full'):
                ['parts', 'var', 'develop-eggs', 'bin', 'lib',
                 'Lib', 'Scripts', join('downloads', 'dist')]]
 
-
     # changes all paths
     if not os.path.isfile(path) and not os.path.isdir(path):
         # let's get the buildout
         if is_svn.search(path) is None:
             raise base.ReleaseError('%s is not a svn url' % path)
-        display(base.system('svn co %s .' % location))
+        output = base.system('svn co %s .' % location)
+        display(output)
+
+    if not os.path.isfile(filename):
+        dirname = os.path.dirname(os.path.abspath(filename))
+        raise base.ReleaseError('%r not found in %r %r (%s)' % (
+            filename, os.getcwd(), root, ', '.join(os.listdir(root))))
 
     display('Using local directory %s with %s' % (target, filename))
 
@@ -487,11 +479,12 @@ def deploy_release(path=None, target=None, archiving='full'):
 
     display(base.system('%s bootstrap.py -c %s' % (python, filename)))
 
-    # let's try to upgrade setuptools and zc.buildout
-    display(base.system('%s -U setuptools' % _easy_install()))
-    display(base.system('%s -U zc.buildout' % _easy_install()))
+    # Force the setuptools / zc.buildout upgrade if requested
+    if force_upgrade:
+        display(base.system('%s -U setuptools' % _easy_install()))
+        display(base.system('%s -U zc.buildout' % _easy_install()))
 
-    # then bin/buildout -v
+    # Run bin/buildout -v
     binary = join('bin', 'buildout')
     buildout = 'buildout.cfg'
 
@@ -505,6 +498,7 @@ def deploy_release(path=None, target=None, archiving='full'):
 
     display('Checking binary.')
     buildout_cmd = '%s %s -c %s' % (binary, buildout_args, filename)
+
     display('Calling %s' % buildout_cmd)
 
     try:
@@ -520,7 +514,7 @@ def deploy_release(path=None, target=None, archiving='full'):
         exit_code, output, errors = runwait(buildout_cmd)
         if exit_code != 0:
             display(errors)
-            raise base.ReleaseError('Fix your buildout')
+            raise base.ReleaseError('Error while running %r. Fix your buildout.' % (buildout_cmd,))
         else:
             sys.stdout.write(output)
             sys.stdout.flush()
@@ -536,7 +530,11 @@ def deploy_release(path=None, target=None, archiving='full'):
         set_option(buildout, 'buildout', 'offline', 'true')
         # let's generate the MD5 stamp that will go in the archive
         display('Generating MD5...')
-        open(join(root, 'MD5'), 'w').write(build_md5(root))
+        fd = open(join(root, 'MD5'), 'w')
+        try:
+            fd.write(build_md5(root))
+        finally:
+            fd.close()
 
         # archiving:
         #  - a full archive
@@ -554,9 +552,9 @@ def deploy_release(path=None, target=None, archiving='full'):
         display('%s ok.' % archive_name)
     finally:
         # setting back the original buildout.cfg file
-        f = open(filename, 'w')
-        f.write(old_content)
-        f.close()
+        fd = open(filename, 'w')
+        fd.write(old_content)
+        fd.close()
         # removing MD5
         os.remove(join(root, 'MD5'))
 
@@ -834,7 +832,9 @@ def project_eggs(cfg, tarball=None, filter_eggs=None, verbose=False):
         config.set('buildout', name, value)
 
     cfg_file = join(tmp, buildout_file)
-    config.write(open(cfg_file, 'w'))
+    fd = open(cfg_file, 'w')
+    config.write(fd)
+    fd.close()
 
     # copying dependencies
     def _copy_extends(config, buildout_dir, tmp):
@@ -985,7 +985,9 @@ def project_eggs(cfg, tarball=None, filter_eggs=None, verbose=False):
                     config.remove_option('buildout', key)
                 if value is not None:
                     config.set('buildout', key, value)
-            config.write(open(file_, 'w'))
+            fd = open(file_, 'w')
+            config.write(fd)
+            fd.close()
 
         to_ = join(install_folder, file_)
         if os.path.exists(to_):
