@@ -13,7 +13,7 @@ from collective.releaser.project import (archive_contents, _python,
                                  diff_releases, _set_dynlibs,
                                  _extract_url,  _make_python,
                                  copy_archives, build_md5, project_eggs,
-                                 deploy_release)
+                                 deploy_release, release_eggs)
 
 from collective.releaser import testing
 from collective.releaser import base
@@ -34,9 +34,11 @@ class ProjectTest(unittest.TestCase):
         previous_snap = ['eggs/file', 'eggs/stuff.egg',
                          'downloads/dist/file', 'downloads/dist/file2']
         self.svn_root = svn_root
+        testing.save(curdir)
 
     def tearDown(self):
         testing.releaserTearDown(self)
+        testing.purge(curdir)
 
     def test_light_archiving(self):
 
@@ -206,26 +208,42 @@ class ProjectTest(unittest.TestCase):
     def test_copy_archives(self):
 
         source = join(os.path.dirname(__file__), 'tarball')
-        target = join(os.path.dirname(__file__), 'tarball2')
-        os.mkdir(target)
-        os.mkdir(join(target, 'downloads'))
-        os.mkdir(join(target, 'eggs'))
+        target = join(os.path.dirname(__file__), 'tarball2.tar.gz')
+
+        # adding cfg file
+        cfg = join(source, 'other.cfg')
+        fd = open(cfg, 'w')
+        fd.write('''[buildout]
+extends = another.cfg
+download-cache = downloads
+parts =
+''')
+        fd.close()
+
+        cfg = join(source, 'another.cfg')
+        fd = open(cfg, 'w')
+        fd.write('''[buildout]
+''')
+        fd.close()
 
         try:
-            copy_archives(source, target)
+            temp = copy_archives(join(source, 'other.cfg'), target, filter_eggs=['*'], clean=False)
             # eggs is not touched because the source doesn't have it
             # downloads existed on the target, so it is renamed
-            res = ['downloads', 'downloads_old', 'eggs', 'eggs_old']
+            res = ['another.cfg', 'buildout.cfg', 'other.cfg', 'downloads', 'eggs']
             res.sort()
-            t = os.listdir(target)
+            t = os.listdir(temp)
             t.sort()
             self.assertEquals(t, res)
 
-            downloads = os.listdir(join(target, 'downloads'))
+            downloads = os.listdir(join(temp, 'downloads'))
             downloads.sort()
             self.assertEquals(downloads, ['dist', 'file.pyc', 'file2'])
+
+            shutil.rmtree(temp)
         finally:
-            shutil.rmtree(target)
+            if os.path.isfile(target):
+                os.remove(target)
 
     def test_build_md5(self):
         source = join(os.path.dirname(__file__), 'tarball')
@@ -315,11 +333,10 @@ class ProjectTest(unittest.TestCase):
                 os.remove(tarball)
         self.assertEquals(original_content, generated_content)
 
-
     def test_deploy_release(self):
         # checking that the process does not try to do a svn checkout
         # and uses the provided folder
-        location = join(os.path.dirname(__file__), 'buildout')
+        location = join(os.path.dirname(__file__), 'buildout', 'buildout.cfg')
         try:
             deploy_release(location)
         finally:
